from managers import (
    BankBilletAccount,
    BankBillet,
    UserInfo,
    Customer,
    Discharge,
    Remittance)

Boleto = BankBillet
ContaBancaria = BankBilletAccount
Usuario = UserInfo
Cliente = Customer
Retorno = Discharge
Remessa = Remittance
